==> geo_comments-6.x-1.0.tar.gz: geo_comments/geo_comments_admin_map.tpl.php <==
<?php
// Load in essential map variables from the database.
$geo_comment_default_map_zoom = variable_get('geo_comment_default_map_zoom', 0);
$geo_comment_min_map_zoom = variable_get('geo_comment_min_map_zoom', 'none');
$geo_comment_max_map_zoom = variable_get('geo_comment_max_map_zoom', 'none');

$geo_comment_map_apply_bounds = variable_get('geo_comment_enable_map_constraints', false);
$geo_comment_map_min_lat = variable_get('geo_comment_map_min_lat', '');
$geo_comment_map_min_lng = variable_get('geo_comment_map_min_lng', '');
$geo_comment_map_max_lat = variable_get('geo_comment_map_max_lat', '');
$geo_comment_map_max_lng = variable_get('geo_comment_map_max_lng', '');

?>
<script type="text/javascript">
<!--
// Wrap the Google Map initialization code in a function.
function initializeGoogleMap() {
  /**
   * Variable definitions.
   */
  var defaultMapZoomLevel = ($('#mapZoomDefault').val() ? $('#mapZoomDefault').val() : 1),
      minMapZoomLevel = <?php echo ($geo_comment_min_map_zoom == 'none') ? 'null' : check_plain($geo_comment_min_map_zoom); ?>,
      maxMapZoomLevel = <?php echo ($geo_comment_max_map_zoom == 'none') ? 'null' : check_plain($geo_comment_max_map_zoom); ?>,
      boundsApply = $('#toggleMapConstraints').is(":checked") ? true : false,
      boundsMinLat = ($('#mapMinLat').val() ? $('#mapMinLat').val() : <?php echo $geo_comment_map_min_lat ? check_plain($geo_comment_map_min_lat) : "''"; ?>),
      boundsMaxLat = ($('#mapMaxLat').val() ? $('#mapMaxLat').val() : <?php echo $geo_comment_map_max_lat ? check_plain($geo_comment_map_max_lat) : "''"; ?>),
      boundsMinLng = ($('#mapMinLng').val() ? $('#mapMinLng').val() : <?php echo $geo_comment_map_min_lng ? check_plain($geo_comment_map_min_lng) : "''"; ?>),
      boundsMaxLng = ($('#mapMaxLng').val() ? $('#mapMaxLng').val() : <?php echo $geo_comment_map_max_lng ? check_plain($geo_comment_map_max_lng) : "''"; ?>);

  /**
   * Map-related objects.
   */
  // Setup the basic map options.
  var mapOptions = {
    zoom: parseInt(defaultMapZoomLevel),
    center: new google.maps.LatLng($('#mapCenterLat').val(), $('#mapCenterLng').val()),
    mapTypeId: google.maps.MapTypeId.ROADMAP
  }
  // Create the Google Map object.
  var map = new google.maps.Map(document.getElementById('google_map_canvas'), mapOptions);
  // Create a bounds object and a rectangle to represent the constrained area on the map.
  var mapPanBounds = new google.maps.LatLngBounds(
    new google.maps.LatLng(boundsMinLat, boundsMinLng),
    new google.maps.LatLng(boundsMaxLat, boundsMaxLng)
  );
  var mapBoundingRect = new google.maps.Rectangle({
    strokeColor: "#9e3d37",
    strokeOpacity: 0.6,
    strokeWeight: 2,
    fillColor: "#ffcccc",
    fillOpacity: 0.2,
    bounds: mapPanBounds,
    editable: true,
    map: map,
    visible: boundsApply
  });
  setBounds(mapBoundingRect);
  // Create a marker that the admin can use to specify a location.
  var markerCenter = new google.maps.Marker({
    draggable: true,
    position: map.getCenter(),
    map: map,
    title: 'Click and drag me to the desired center-point of your map'
  });

  /**
   * Interface events.
   */
  // Listen for 'bounds changed' on the user-adjustable bounding rectangle.
  google.maps.event.addListener(mapBoundingRect, 'bounds_changed', function () {
    setBounds(this);
  });
  // Listen for the user turning the bounding rectangle on and off.
  google.maps.event.addDomListener(document.getElementById('toggleMapConstraints'), 'change', function (event) {
    if (event.target.checked) {
      // Make the rectangle visible on the map and record its co-ordinates in the form.
      mapBoundingRect.setVisible(true);
      setBounds(mapBoundingRect);
    }
    else {
      // Make the rectangle invisible and empty the co-ordinates form fields.
      mapBoundingRect.setVisible(false);
      resetBounds();
    }
  });
  // Listen for 'drag end' events on the marker and record the dropped location.
  google.maps.event.addListener(markerCenter, 'dragend', function (event) {
    setCenter(event.latLng);
  });
  // Listen for 'zoom changed' events and, if necessary, constrain the zoom level to the levels specified in the Geo-comments admin.
  google.maps.event.addListener(map, 'zoom_changed', function() {
    var was = map.getZoom();
    if (minMapZoomLevel != null && map.getZoom() < minMapZoomLevel) {
      map.setZoom(minMapZoomLevel);
    }
    if (maxMapZoomLevel != null && map.getZoom() > maxMapZoomLevel) {
      map.setZoom(maxMapZoomLevel);
    }
  });

  /**
   * Helper functions.
   */
  // Assign the coordinates of the given rectangle to the appropriate form fields.
  function setBounds(boundingRect) {
    var boundSW = boundingRect.bounds.getSouthWest(),
        boundNE = boundingRect.bounds.getNorthEast();
    $('#mapMinLat').val(boundSW.lat().toFixed(5));
    $('#mapMaxLat').val(boundNE.lat().toFixed(5));
    $('#mapMinLng').val(boundSW.lng().toFixed(5));
    $('#mapMaxLng').val(boundNE.lng().toFixed(5));
  }
  // Empty the form fields for the map bounding rectangle.
  function resetBounds() {
    $('#mapMinLat').val('');
    $('#mapMaxLat').val('');
    $('#mapMinLng').val('');
    $('#mapMaxLng').val('');
  }
  // Assign the coordinates of the given point to the appropriate form fields.
  function setCenter(latLng) {
    $('#mapCenterLat').val(latLng.lat().toFixed(5));
    $('#mapCenterLng').val(latLng.lng().toFixed(5));
  }
}

// Trigger loading of the Google Map javascript on doc ready.
$(function(){
  // Trigger the Google Map loading process asynchronously once the document has loaded.
  function loadGoogleMapScript() {
    var script = document.createElement('script');
    script.type = 'text/javascript';
    script.src = 'http://maps.googleapis.com/maps/api/js?sensor=false&callback=initializeGoogleMap';
    document.body.appendChild(script);
  }
  loadGoogleMapScript();
});
-->
</script>

<div class="form-item">
  <label>Configure the Geo-comments map:</label>
  <div id="google_map_canvas" style="width: 400px; height: 300px;"></div>
  <div class="description">Drag the map marker to set the default center-point of the map.</div>
</div>

==> geo_comments-6.x-1.1.tar.gz: geo_comments/geo_comments_admin_map.tpl.php <==
<?php
// Load in essential map variables from the database.
$geo_comment_default_map_zoom = variable_get('geo_comment_default_map_zoom', 0);
$geo_comment_min_map_zoom = variable_get('geo_comment_min_map_zoom', 'none');
$geo_comment_max_map_zoom = variable_get('geo_comment_max_map_zoom', 'none');

$geo_comment_map_apply_bounds = variable_get('geo_comment_enable_map_constraints', false);
$geo_comment_map_min_lat = variable_get('geo_comment_map_min_lat', '');
$geo_comment_map_min_lng = variable_get('geo_comment_map_min_lng', '');
$geo_comment_map_max_lat = variable_get('geo_comment_map_max_lat', '');
$geo_comment_map_max_lng = variable_get('geo_comment_map_max_lng', '');

?>
<script type="text/javascript">
<!--
// Wrap the Google Map initialization code in a function.
function initializeGoogleMap() {
  /**
   * Variable definitions.
   */
  var defaultMapZoomLevel = ($('#mapZoomDefault').val() ? $('#mapZoomDefault').val() : 1),
      minMapZoomLevel = <?php echo ($geo_comment_min_map_zoom == 'none') ? 'null' : check_plain($geo_comment_min_map_zoom); ?>,
      maxMapZoomLevel = <?php echo ($geo_comment_max_map_zoom == 'none') ? 'null' : check_plain($geo_comment_max_map_zoom); ?>,
      boundsApply = $('#toggleMapConstraints').is(":checked") ? true : false,
      boundsMinLat = ($('#mapMinLat').val() ? $('#mapMinLat').val() : <?php echo $geo_comment_map_min_lat ? check_plain($geo_comment_map_min_lat) : "''"; ?>),
      boundsMaxLat = ($('#mapMaxLat').val() ? $('#mapMaxLat').val() : <?php echo $geo_comment_map_max_lat ? check_plain($geo_comment_map_max_lat) : "''"; ?>),
      boundsMinLng = ($('#mapMinLng').val() ? $('#mapMinLng').val() : <?php echo $geo_comment_map_min_lng ? check_plain($geo_comment_map_min_lng) : "''"; ?>),
      boundsMaxLng = ($('#mapMaxLng').val() ? $('#mapMaxLng').val() : <?php echo $geo_comment_map_max_lng ? check_plain($geo_comment_map_max_lng) : "''"; ?>);

  /**
   * Map-related objects.
   */
  // Setup the basic map options.
  var mapOptions = {
    zoom: parseInt(defaultMapZoomLevel),
    center: new google.maps.LatLng($('#mapCenterLat').val(), $('#mapCenterLng').val()),
    mapTypeId: google.maps.MapTypeId.ROADMAP
  }
  // Create the Google Map object.
  var map = new google.maps.Map(document.getElementById('google_map_canvas'), mapOptions);
  // Create a marker that the admin can use to specify a location.
  var markerCenter = new google.maps.Marker({
    draggable: true,
    position: map.getCenter(),
    map: map,
    title: 'Click and drag me to the desired center-point of your map'
  });
  // Create a bounds object and a rectangle to represent the constrained area on the map.
  var mapPanBounds = getMapPanBounds();
  var mapBoundingRect = new google.maps.Rectangle({
    strokeColor: "#9e3d37",
    strokeOpacity: 0.6,
    strokeWeight: 2,
    fillColor: "#ffcccc",
    fillOpacity: 0.2,
    bounds: mapPanBounds,
    editable: true,
    map: map,
    visible: boundsApply
  });
  storeBounds(mapBoundingRect);

  /**
   * Interface events.
   */
  // Listen for 'bounds changed' on the user-adjustable bounding rectangle.
  google.maps.event.addListener(mapBoundingRect, 'bounds_changed', function () {
    storeBounds(this);
  });
  // Listen for the user turning the bounding rectangle on and off.
  google.maps.event.addDomListener(document.getElementById('toggleMapConstraints'), 'change', function (event) {
    if (event.target.checked) {
      // Make the rectangle visible on the map and record its co-ordinates in the form.
      mapBoundingRect.setBounds(getMapPanBounds());
      mapBoundingRect.setVisible(true);
      storeBounds(mapBoundingRect);
    }
    else {
      // Make the rectangle invisible and empty the co-ordinates form fields.
      mapBoundingRect.setVisible(false);
      resetBounds();
    }
  });
  // Listen for 'drag end' events on the marker and record the dropped location.
  google.maps.event.addListener(markerCenter, 'dragend', function (event) {
    setCenter(event.latLng);
  });

  /**
   * Helper functions.
   */
  // Assign the coordinates of the given rectangle to the appropriate form fields.
  function storeBounds(boundingRect) {
    var boundSW = boundingRect.bounds.getSouthWest(),
        boundNE = boundingRect.bounds.getNorthEast();
    $('#mapMinLat').val(boundSW.lat().toFixed(5));
    $('#mapMaxLat').val(boundNE.lat().toFixed(5));
    $('#mapMinLng').val(boundSW.lng().toFixed(5));
    $('#mapMaxLng').val(boundNE.lng().toFixed(5));
  }
  // Empty the form fields for the map bounding rectangle.
  function resetBounds() {
    $('#mapMinLat').val('');
    $('#mapMaxLat').val('');
    $('#mapMinLng').val('');
    $('#mapMaxLng').val('');
  }
  // Assign the coordinates of the given point to the appropriate form fields.
  function setCenter(latLng) {
    $('#mapCenterLat').val(latLng.lat().toFixed(5));
    $('#mapCenterLng').val(latLng.lng().toFixed(5));
  }
  // Generate a location for the bounding rectangle, returning either the
  // previously saved bounds, or generating a new location from the map marker.
  function getMapPanBounds() {
    if (boundsMinLat) {
      return new google.maps.LatLngBounds(
        new google.maps.LatLng(boundsMinLat, boundsMinLng),
        new google.maps.LatLng(boundsMaxLat, boundsMaxLng)
      );
    }
    else {
      return new google.maps.LatLngBounds(
        new google.maps.LatLng(markerCenter.position.lat() - 7.5, markerCenter.position.lng() - 12.5),
        new google.maps.LatLng(markerCenter.position.lat() + 7.5, markerCenter.position.lng() + 12.5)
      );
    }
  }
}

// Trigger loading of the Google Map javascript on doc ready.
$(function(){
  // Trigger the Google Map loading process asynchronously once the document has loaded.
  function loadGoogleMapScript() {
    var script = document.createElement('script');
    script.type = 'text/javascript';
    script.src = 'http://maps.googleapis.com/maps/api/js?sensor=false&callback=initializeGoogleMap';
    document.body.appendChild(script);
  }
  loadGoogleMapScript();
});
-->
</script>

<div class="form-item">
  <label>Configure the Geo-comments map:</label>
  <div id="google_map_canvas" style="width: 500px; height: 350px;"></div>
  <div class="description">Drag the map marker to set the default center-point of the map.</div>
</div>
